@@ -1,13 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-mem" "0.34.0"
+(define-package "org-mem" "20251015.1247"
   "Fast info from a large number of Org file contents."
-  '((emacs          "29.1")
-    (el-job         "2.7.3")
-    (llama          "1.0")
-    (truename-cache "0.3.2"))
+  '((emacs  "29.1")
+    (el-job "2.4.8")
+    (llama  "0.5.0"))
   :url "https://github.com/meedstrom/org-mem"
-  :commit "a37b885c46b086611b43841e666a5a9f57190b2f"
-  :revdesc "0.34.0-0-ga37b885c46b0"
+  :commit "7c05f83accaa012bc789ba7c63d7035b0688dadf"
+  :revdesc "7c05f83accaa"
   :keywords '("text")
   :authors '(("Martin Edström" . "meedstrom@runbox.eu"))
   :maintainers '(("Martin Edström" . "meedstrom@runbox.eu")))
